@@ -246,7 +246,7 @@ mod utils;
 
 use syn::{parse_macro_input, ItemFn};
 
-use crate::parse::{fixture::FixtureInfo, rstest::RsTestInfo};
+use crate::parse::{fixture::FixtureInfo, future::ReplaceFutureAttribute, rstest::RsTestInfo};
 use parse::ExtendWithFunctionAttrs;
 use quote::ToTokens;
 
@@ -322,18 +322,49 @@ use quote::ToTokens;
 ///
 /// ```
 /// use rstest::*;
-/// # use std::future::Future;
 ///
 /// #[fixture]
 /// async fn async_fixture() -> i32 { 42 }
 ///
 ///
 /// #[rstest]
-/// async fn the_test(async_fixture: impl Future<Output = i32>) {
+/// async fn the_test(#[future] async_fixture: i32) {
 ///     assert_eq!(42, async_fixture.await)
 /// }
 /// ```
+/// The `#[future]` argument attribute helps to remove the `impl Future<Output = T>` boilerplate.
+/// In this case the macro expands it in:
 ///
+/// ```
+/// # use rstest::*;
+/// # use std::future::Future;
+/// # #[fixture]
+/// # async fn async_fixture() -> i32 { 42 }
+/// #[rstest]
+/// async fn the_test(async_fixture: impl std::future::Future<Output = i32>) {
+///     assert_eq!(42, async_fixture.await)
+/// }
+/// ```
+/// If you need, you can use `#[future]` attribute also with an implicit lifetime reference
+/// because the macro will replace the implicit lifetime with an explicit one.
+///
+/// # Rename
+///
+/// Sometimes you want to have long and descriptive name for your fixture but you prefer to use a much
+/// shorter name for argument that represent it in your fixture or test. You can rename the fixture
+/// using `#[from(short_name)]` attribute like following example:
+///
+/// ```
+/// use rstest::*;
+///
+/// #[fixture]
+/// fn long_and_boring_descriptive_name() -> i32 { 42 }
+///
+/// #[rstest]
+/// fn the_test(#[from(long_and_boring_descriptive_name)] short: i32) {
+///     assert_eq!(42, short)
+/// }
+/// ```
 ///
 /// # Partial Injection
 ///
@@ -363,7 +394,6 @@ use quote::ToTokens;
 /// attribute will inject `v1, ..., vn` expression as fixture arguments: all remaining arguments
 /// will be resolved as fixtures.
 ///
-///
 /// Sometimes the return type cannot be infered so you must define it: For the few times you may
 /// need to do it, you can use the `#[default(type)]`, `#[partial_n(type)]` function attribute
 /// to define it:
@@ -415,6 +445,19 @@ use quote::ToTokens;
 /// #[fixture(twenty_one=21, two=2)]
 /// fn injected(twenty_one: i32, two: i32) -> i32 { twenty_one * two }
 /// ```
+///
+/// ## Rename
+/// ```
+/// # use rstest::*;
+/// #[fixture]
+/// fn long_and_boring_descriptive_name() -> i32 { 42 }
+///
+/// #[rstest(long_and_boring_descriptive_name as short)]
+/// fn the_test(short: i32) {
+///     assert_eq!(42, short)
+/// }
+/// ```
+///
 /// ## Partial Injection
 /// ```
 /// # use rstest::*;
@@ -459,10 +502,14 @@ pub fn fixture(
     let mut info: FixtureInfo = parse_macro_input!(args as FixtureInfo);
     let mut fixture = parse_macro_input!(input as ItemFn);
 
+    let replace_result = ReplaceFutureAttribute::replace(&mut fixture);
     let extend_result = info.extend_with_function_attrs(&mut fixture);
 
     let mut errors = error::fixture(&fixture, &info);
 
+    if let Err(attrs_errors) = replace_result {
+        attrs_errors.to_tokens(&mut errors);
+    }
     if let Err(attrs_errors) = extend_result {
         attrs_errors.to_tokens(&mut errors);
     }
@@ -530,6 +577,22 @@ pub fn fixture(
 /// }
 /// ```
 ///
+/// If you want to use long and descriptive names for your fixture but prefer to use
+/// shorter names inside your tests you use rename feature described in 
+/// [fixture rename](attr.fixture.html#rename):
+///
+/// ```
+/// use rstest::*;
+///
+/// #[fixture]
+/// fn long_and_boring_descriptive_name() -> i32 { 42 }
+///
+/// #[rstest]
+/// fn the_test(#[from(long_and_boring_descriptive_name)] short: i32) {
+///     assert_eq!(42, short)
+/// }
+/// ```
+///
 /// Sometimes is useful to have some parametes in your fixtures but your test would
 /// override the fixture's default values in some cases. Like in
 /// [fixture partial injection](attr.fixture.html#partial-injection) you use `#[with]`
@@ -839,6 +902,22 @@ pub fn fixture(
 /// async-std = { version = "1.5", features = ["attributes"] }
 /// ```
 ///
+/// If your test input is an async value (fixture or test parameter) you can use `#[future]`
+/// attribute to remove `impl Future<Output = T>` boilerplate and just use `T`:
+///
+/// ```
+/// use rstest::*;
+/// #[fixture]
+/// async fn base() -> u32 { 42 }
+///
+/// #[rstest]
+/// #[case(21, async { 2 })]
+/// #[case(6, async { 7 })]
+/// async fn my_async_test(#[future] base: u32, #[case] expected: u32, #[future] #[case] div: u32) {
+///     assert_eq!(expected, base.await / div.await);
+/// }
+/// ```
+///
 /// ## Inject Test Attribute
 ///
 /// If you would like to use another `test` attribute for your test you can simply
@@ -854,7 +933,7 @@ pub fn fixture(
 /// #[case(2, async { 4 })]
 /// #[case(21, async { 42 })]
 /// #[actix_rt::test]
-/// async fn my_async_test(#[case] a: u32, #[case] result: impl Future<Output=u32>) {
+/// async fn my_async_test(#[case] a: u32, #[case] #[future] result: u32) {
 ///     assert_eq!(2 * a, result.await);
 /// }
 /// ```
@@ -987,7 +1066,8 @@ pub fn fixture(
 /// - `arg_i` could be one of the follow
 ///   - `ident` that match to one of function arguments for parametrized cases
 ///   - `case[::description](v1, ..., vl)` a test case
-///   - `fixture(v1, ..., vl)` where fixture is one of function arguments
+///   - `fixture(v1, ..., vl) [as argument_name]` where fixture is the injected
+/// fixture and argument_name (default use fixture) is one of function arguments
 /// that and `v1, ..., vl` is a partial list of fixture's arguments
 ///   - `ident => [v1, ..., vl]` where `ident` is one of function arguments and
 /// `v1, ..., vl` is a list of values for ident
@@ -1012,6 +1092,18 @@ pub fn fixture(
 /// }
 /// ```
 ///
+/// ## Fixture Rename
+/// ```
+/// # use rstest::*;
+/// #[fixture]
+/// fn long_and_boring_descriptive_name() -> i32 { 42 }
+///
+/// #[rstest(long_and_boring_descriptive_name as short)]
+/// fn the_test(short: i32) {
+///     assert_eq!(42, short)
+/// }
+/// ```
+///
 /// ## Parametrized
 ///
 /// ```
@@ -1071,10 +1163,14 @@ pub fn rstest(
     let mut test = parse_macro_input!(input as ItemFn);
     let mut info = parse_macro_input!(args as RsTestInfo);
 
+    let replace_result = ReplaceFutureAttribute::replace(&mut test);
     let extend_result = info.extend_with_function_attrs(&mut test);
 
     let mut errors = error::rstest(&test, &info);
 
+    if let Err(attrs_errors) = replace_result {
+        attrs_errors.to_tokens(&mut errors);
+    }
     if let Err(attrs_errors) = extend_result {
         attrs_errors.to_tokens(&mut errors);
     }
