@@ -2,7 +2,7 @@ use std::path::Path;
 
 use super::resources;
 
-use rstest::*;
+use mytest::*;
 use rstest_test::*;
 use unindent::Unindent;
 
@@ -460,6 +460,7 @@ mod cases {
             .fail("my_async_test::case_2_fail")
             .ok("my_async_test::case_3_pass_panic")
             .fail("my_async_test::case_4_fail_panic")
+            .ok("my_async_test_revert::case_1_pass")
             .assert(output);
     }
 
@@ -870,6 +871,18 @@ fn happy_path() {
         .assert(output);
 }
 
+#[test]
+fn rename() {
+    let (output, _) = run_test("rename.rs");
+
+    TestResults::new()
+        .ok("compact")
+        .ok("compact_injected")
+        .ok("attribute")
+        .ok("attribute_injected")
+        .assert(output);
+}
+
 mod should_show_correct_errors {
     use std::process::Output;
 
@@ -1275,4 +1288,42 @@ mod should_show_correct_errors {
             .unindent()
         );
     }
+
+    #[test]
+    fn if_try_to_use_future_on_an_impl() {
+        let (output, name) = execute();
+
+        assert_in!(
+            output.stderr.str(),
+            format!(
+                "
+                  --> {}/src/lib.rs:90:57
+                   |
+                90 | async fn error_future_on_impl_type(#[case] #[future] s: impl AsRef<str>) {{}}
+                   |                                                         ^^^^^^^^^^^^^^^
+                ",
+                name
+            )
+            .unindent()
+        );
+    }
+
+    #[test]
+    fn if_try_to_use_future_more_that_once() {
+        let (output, name) = execute();
+
+        assert_in!(
+            output.stderr.str(),
+            format!(
+                "
+                  --> {}/src/lib.rs:94:54
+                   |
+                94 | async fn error_future_on_impl_type(#[case] #[future] #[future] a: i32) {{}}
+                   |                                                      ^^^^^^^^^
+                ",
+                name
+            )
+            .unindent()
+        );
+    }
 }
